@@ -6,25 +6,13 @@ import bisect
 import itertools
 import json
 import logging
-import math
 import operator
 import struct
 from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 from functools import reduce
 from hashlib import sha256
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    List,
-    Optional,
-    Set,
-    Tuple,
-    TypeVar,
-    Union,
-    cast,
-)
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Tuple, Union, cast
 
 from psycopg2._json import Json
 from psycopg2.errors import UniqueViolation
@@ -33,11 +21,12 @@ from splitgraph.config import CONFIG, SG_CMD_ASCII, SPLITGRAPH_API_SCHEMA, get_s
 from splitgraph.core.indexing.bloom import filter_bloom_index, generate_bloom_index
 from splitgraph.core.indexing.range import filter_range_index, generate_range_index
 from splitgraph.core.metadata_manager import MetadataManager, Object
-from splitgraph.core.types import Changeset, Comparable, TableSchema
+from splitgraph.core.types import Changeset, TableSchema
 from splitgraph.engine import ResultShape
 from splitgraph.engine.postgres.engine import (
     SG_UD_FLAG,
     add_ud_flag_column,
+    chunk,
     get_change_key,
 )
 from splitgraph.exceptions import SplitGraphError
@@ -198,10 +187,14 @@ class Digest:
     # In these routines, we treat each hash as a vector of 16 2-byte integers and do component-wise addition.
     # To simulate the wraparound behaviour of C shorts, throw away all remaining bits after the action.
     def __add__(self, other: "Digest") -> "Digest":
-        return Digest(tuple((l + r) & 0xFFFF for l, r in zip(self.shorts, other.shorts)))
+        return Digest(
+            tuple((left + right) & 0xFFFF for left, right in zip(self.shorts, other.shorts))
+        )
 
     def __sub__(self, other: "Digest") -> "Digest":
-        return Digest(tuple((l - r) & 0xFFFF for l, r in zip(self.shorts, other.shorts)))
+        return Digest(
+            tuple((left - right) & 0xFFFF for left, right in zip(self.shorts, other.shorts))
+        )
 
     def __neg__(self) -> "Digest":
         return Digest(tuple(-v & 0xFFFF for v in self.shorts))
@@ -1149,6 +1142,44 @@ class FragmentManager(MetadataManager):
         # Preserve original object order.
         return [r for r in object_ids if r in objects_to_scan]
 
+    def generate_surrogate_pk(
+        self, table: "Table", object_pks: List[Tuple[Any, Any]]
+    ) -> List[Tuple[Any, Any]]:
+        """
+        When partitioning data, if the table doesn't have a primary key, we use a "surrogate"
+        primary key by concatenating the whole row as a string on the PG side (this is because
+        the whole row can sometimes contain NULLs which we can't compare in PG).
+
+        We need to mimic this when calculating if the objects we're about to scan through
+        overlap: e.g. using string comparison, "(some_country, 100)" < "(some_country, 20)",
+        whereas using typed comparison, (some_country, 100) > (some_country, 20).
+
+        To do this, we use a similar hack from when calculating changeset hashes: to avoid having
+        to reproduce how PG's ::text works, we give it back the rows and get it to cast them
+        to text for us.
+        """
+        inner_tuple = (
+            "(" + ",".join("%s::" + ct for _, ct in get_change_key(table.table_schema)) + ")"
+        )
+        rows = [r for o in object_pks for r in o]
+
+        result = []
+        for batch in chunk(rows, 1000):
+            query = (  # nosec
+                "SELECT o::text FROM (VALUES "
+                + ",".join(itertools.repeat(inner_tuple, len(batch)))
+                + ") o"
+            )
+            result.extend(
+                self.object_engine.run_sql(
+                    query,
+                    [o if not isinstance(o, dict) else Json(o) for row in batch for o in row],
+                    return_shape=ResultShape.MANY_ONE,
+                )
+            )
+        object_pks = list(zip(result[::2], result[1::2]))
+        return object_pks
+
     def _add_overlapping_objects(
         self, table: "Table", all_objects: List[str], filtered_objects: List[str]
     ) -> Set[str]:
@@ -1159,6 +1190,10 @@ class FragmentManager(MetadataManager):
         table_pk = get_change_key(table.table_schema)
         object_pks = self.get_min_max_pks(all_objects, table_pk)
 
+        surrogate_pk = not any(t.is_pk for t in table.table_schema)
+        if surrogate_pk:
+            object_pks = self.generate_surrogate_pk(table, object_pks)
+
         # Go through all objects and see if they 1) come after any of our chosen objects and 2)
         # overlap those objects' PKs (if they come after them)
         original_order = {object_id: i for i, object_id in enumerate(all_objects)}
