@@ -7,23 +7,22 @@ import logging
 import sys
 import time
 from contextlib import contextmanager
-from io import BytesIO
-from io import TextIOWrapper
+from io import BytesIO, TextIOWrapper
 from pathlib import PurePosixPath
 from threading import get_ident
 from typing import (
+    TYPE_CHECKING,
     Any,
     Dict,
+    Iterable,
     Iterator,
     List,
     Optional,
-    Tuple,
-    Union,
-    TYPE_CHECKING,
     Sequence,
-    cast,
+    Tuple,
     TypeVar,
-    Iterable,
+    Union,
+    cast,
 )
 
 import psycopg2
@@ -31,29 +30,38 @@ import psycopg2.extensions
 from packaging.version import Version
 from psycopg2 import DatabaseError
 from psycopg2.errors import InvalidSchemaName, UndefinedTable
-from psycopg2.extras import execute_batch, Json
-from psycopg2.pool import ThreadedConnectionPool, AbstractConnectionPool
-from psycopg2.sql import Composed, SQL
-from psycopg2.sql import Identifier
-from tqdm import tqdm
-
+from psycopg2.extras import Json
+from psycopg2.pool import AbstractConnectionPool, ThreadedConnectionPool
+from psycopg2.sql import SQL, Composed, Identifier
 from splitgraph.__version__ import __version__
-from splitgraph.config import SPLITGRAPH_META_SCHEMA, CONFIG, SPLITGRAPH_API_SCHEMA, SG_CMD_ASCII
+from splitgraph.config import (
+    CONFIG,
+    SG_CMD_ASCII,
+    SPLITGRAPH_API_SCHEMA,
+    SPLITGRAPH_META_SCHEMA,
+)
 from splitgraph.core import server
-from splitgraph.core.common import ensure_metadata_schema, META_TABLES
+from splitgraph.core.common import META_TABLES, ensure_metadata_schema
 from splitgraph.core.sql import select
 from splitgraph.core.types import TableColumn, TableSchema
-from splitgraph.engine import ResultShape, ObjectEngine, ChangeEngine, SQLEngine, switch_engine
+from splitgraph.engine import (
+    ChangeEngine,
+    ObjectEngine,
+    ResultShape,
+    SQLEngine,
+    switch_engine,
+)
 from splitgraph.exceptions import (
-    EngineInitializationError,
-    ObjectNotFoundError,
-    AuthAPIError,
-    IncompleteObjectDownloadError,
     APICompatibilityError,
+    AuthAPIError,
+    EngineInitializationError,
+    IncompleteObjectDownloadError,
     ObjectMountingError,
+    ObjectNotFoundError,
 )
 from splitgraph.hooks.mount_handlers import mount_postgres
 from splitgraph.resources import static
+from tqdm import tqdm
 
 if TYPE_CHECKING:
     # Import the connection object under a different name as it shadows
@@ -92,7 +100,7 @@ API_MAX_QUERY_LENGTH = 261000
 # In addition, some API calls (like get_object_meta) allow variadic arguments
 # to decrease the number of roundtrips the client has to do -- limit this to a sane
 # number.
-API_MAX_VARIADIC_ARGS = 1000
+API_MAX_VARIADIC_ARGS = 100
 
 
 # PG types we can run max/min/comparisons on
@@ -172,13 +180,10 @@ T = TypeVar("T")
 
 def chunk(sequence: Sequence[T], chunk_size: int = API_MAX_VARIADIC_ARGS) -> Iterator[List[T]]:
     curr_chunk: List[T] = []
-    i = 0
-    for curr in sequence:
-        i += 1
+    for i, curr in enumerate(sequence):
         curr_chunk.append(curr)
-        if i >= chunk_size:
+        if (i + 1) % chunk_size == 0:
             yield curr_chunk
-            i = 0
             curr_chunk = []
     if curr_chunk:
         yield curr_chunk
