@@ -5,19 +5,18 @@ import re
 from abc import ABC
 from contextlib import contextmanager
 from random import getrandbits
-from typing import Optional, Dict, List, Tuple, Generator
+from typing import Dict, Generator, List, Optional, Tuple
 
 import docker.errors
 import pydantic
 from docker import DockerClient
 from docker.models.containers import Container
 from docker.types import LogConfig
-
 from splitgraph.core.repository import Repository
 from splitgraph.core.types import (
+    IntrospectionResult,
     SyncState,
     TableInfo,
-    IntrospectionResult,
     TableParams,
     get_table_params,
 )
@@ -27,30 +26,28 @@ from splitgraph.hooks.data_source.base import (
     get_ingestion_state,
     prepare_new_image,
 )
-from splitgraph.utils.docker import get_docker_client, copy_to_container
+from splitgraph.utils.docker import copy_to_container, get_docker_client
+
+from ..common import add_timestamp_tags
+from ..dbt.utils import run_dbt_transformation_from_git
+from ..singer.common import store_ingestion_state
 from .docker_utils import (
     add_files,
-    remove_at_end,
-    wait_not_failed,
     build_command,
     detect_network_mode,
+    remove_at_end,
+    wait_not_failed,
 )
-from .models import (
-    AirbyteCatalog,
-    ConfiguredAirbyteCatalog,
-    AirbyteMessage,
-)
+from .models import AirbyteCatalog, AirbyteMessage, ConfiguredAirbyteCatalog
 from .utils import (
     AirbyteConfig,
     _airbyte_message_reader,
-    _store_raw_airbyte_tables,
     _store_processed_airbyte_tables,
+    _store_raw_airbyte_tables,
+    get_pk_cursor_fields,
     get_sg_schema,
     select_streams,
-    get_pk_cursor_fields,
 )
-from ..dbt.utils import run_dbt_transformation_from_git
-from ..singer.common import store_ingestion_state, add_timestamp_tags
 
 
 @contextmanager
@@ -69,8 +66,8 @@ class AirbyteDataSource(SyncableDataSource, ABC):
 
     docker_image: Optional[str] = None
     airbyte_name: Optional[str] = None
-    receiver_image = "airbyte/destination-postgres:latest"
-    normalization_image = "airbyte/normalization:0.1.36"
+    receiver_image = "airbyte/destination-postgres:0.3.12"
+    normalization_image = "airbyte/normalization:0.1.59"
     cursor_overrides: Optional[Dict[str, List[str]]] = None
     primary_key_overrides: Optional[Dict[str, List[str]]] = None
     docker_environment: Optional[Dict[str, str]] = None
@@ -80,12 +77,14 @@ class AirbyteDataSource(SyncableDataSource, ABC):
         "properties": {
             "airbyte_cursor_fields": {
                 "type": "array",
+                "title": "Cursor field(s)",
                 "description": "Fields in this stream to be used as a cursor "
                 "for incremental replication (overrides Airbyte configuration's cursor_field)",
                 "items": {"type": "string"},
             },
             "airbyte_primary_key_fields": {
                 "type": "array",
+                "title": "Primary key field(s)",
                 "description": "Fields in this stream to be used as a primary key for deduplication "
                 "(overrides Airbyte configuration's primary_key)",
                 "items": {"type": "string"},
@@ -102,7 +101,7 @@ class AirbyteDataSource(SyncableDataSource, ABC):
     #       {"type": "object", "properties": {...}},
     #   )
     #   params_schema = merge_jsonschema(
-    #       AirbyteDataSource.credentials_schema,
+    #       AirbyteDataSource.params_schema,
     #       {"type": "object", "properties": {...}},
     #   )
     params_schema = {
@@ -110,6 +109,7 @@ class AirbyteDataSource(SyncableDataSource, ABC):
         "properties": {
             "normalization_mode": {
                 "type": "string",
+                "title": "Post-ingestion normalization",
                 "description": "Whether to normalize raw Airbyte tables. "
                 "`none` is no normalization, `basic` is Airbyte's basic normalization, "
                 "`custom` is a custom dbt transformation on the data.",
@@ -118,6 +118,7 @@ class AirbyteDataSource(SyncableDataSource, ABC):
             },
             "normalization_git_branch": {
                 "type": "string",
+                "title": "dbt model Git branch",
                 "description": "Branch or commit hash to use for the normalization dbt project.",
                 "default": "master",
             },
@@ -130,6 +131,7 @@ class AirbyteDataSource(SyncableDataSource, ABC):
             # This is a secret since the git URL might have a password in it.
             "normalization_git_url": {
                 "type": "string",
+                "title": "dbt model Git URL",
                 "description": "For `custom` normalization, a URL to the Git repo "
                 "with the dbt project, for example,"
                 "`https://uname:pass_or_token@github.com/organisation/repository.git`.",
@@ -167,6 +169,7 @@ class AirbyteDataSource(SyncableDataSource, ABC):
             "password": engine.conn_params["SG_ENGINE_PWD"],
             "database": engine.conn_params["SG_ENGINE_DB_NAME"],
             "schema": schema,
+            "ssl": False,
         }
 
     def _run_discovery(self, config: Optional[AirbyteConfig] = None) -> AirbyteCatalog:
