@@ -1,20 +1,26 @@
 import logging
-from typing import Dict, Any, Iterable, Generator, Optional, List, Tuple
-
-from target_postgres.db_sync import column_type
+from typing import Any, Dict, Generator, Iterable, List, Optional, Tuple
 
 from splitgraph.config import DEFAULT_CHUNK_SIZE
 from splitgraph.core.repository import Repository
-from splitgraph.core.types import TableSchema, TableColumn, TableInfo, TableParams, get_table_params
+from splitgraph.core.types import (
+    TableColumn,
+    TableInfo,
+    TableParams,
+    TableSchema,
+    get_table_params,
+)
 from splitgraph.exceptions import TableNotFoundError
+from target_postgres.db_sync import column_type
+
 from .models import (
+    AirbyteCatalog,
     AirbyteMessage,
     AirbyteStream,
-    AirbyteCatalog,
     ConfiguredAirbyteCatalog,
     ConfiguredAirbyteStream,
-    SyncMode,
     DestinationSyncMode,
+    SyncMode,
 )
 
 AirbyteConfig = Dict[str, Any]
@@ -213,6 +219,13 @@ def select_streams(
             primary_key_overrides,
         )
 
+        # Fix for a weird bug in the file source where the JSONSchema
+        # contains "properties" inside of a "properties" object for some reason.
+        if "properties" in stream.json_schema["properties"] and isinstance(
+            stream.json_schema["properties"]["properties"], dict
+        ):
+            stream.json_schema["properties"] = stream.json_schema["properties"]["properties"]
+
         sync_configured = False
         if sync:
             if (
