@@ -1,12 +1,12 @@
 from abc import abstractmethod
-from typing import Optional, Union, Dict, List, Tuple
+from datetime import datetime as dt
+from typing import Dict, List, Optional, Tuple, Union
 
 from psycopg2.sql import SQL, Identifier
-
 from splitgraph.core.image import Image
 from splitgraph.core.repository import Repository
 from splitgraph.core.sql import POSTGRES_MAX_IDENTIFIER
-from splitgraph.core.types import TableSchema, TableColumn
+from splitgraph.core.types import TableColumn, TableSchema
 from splitgraph.engine.postgres.engine import PsycopgEngine
 from splitgraph.exceptions import CheckoutError
 
@@ -21,12 +21,10 @@ def schema_compatible(source_schema: TableSchema, target_schema: TableSchema) ->
     if len(source_schema) != len(target_schema):
         return False
 
-    for col1, col2 in zip(sorted(source_schema), sorted(target_schema)):
-        # Only check column names
-        if col1.name != col2.name:
-            return False
-
-    return True
+    # Only check column names
+    return all(
+        col1.name == col2.name for col1, col2 in zip(sorted(source_schema), sorted(target_schema))
+    )
 
 
 def merge_tables(
@@ -277,3 +275,12 @@ def build_commandline_help(json_schema):
     return "\n".join(
         _format_jsonschema(p, pd, required) for p, pd in json_schema["properties"].items()
     )
+
+
+def add_timestamp_tags(repository: Repository, image_hash: str):
+    ingestion_time = dt.utcnow()
+    short_tag = ingestion_time.strftime("%Y%m%d")
+    long_tag = short_tag + "-" + ingestion_time.strftime("%H%M%S")
+    new_image = repository.images.by_hash(image_hash)
+    new_image.tag(short_tag)
+    new_image.tag(long_tag)
