@@ -7,14 +7,13 @@ import logging
 from hashlib import sha256
 from importlib import import_module
 from random import getrandbits
-from typing import Callable, Dict, List, Optional, cast, Tuple
+from typing import Callable, Dict, List, Optional, Tuple, cast
 
 from parsimonious.nodes import Node
 from psycopg2.sql import SQL, Identifier
-
 from splitgraph.config import CONFIG
 from splitgraph.config.config import get_all_in_section, get_singleton
-from splitgraph.core.engine import repository_exists, lookup_repository
+from splitgraph.core.engine import lookup_repository, repository_exists
 from splitgraph.core.image import Image
 from splitgraph.core.repository import Repository, clone
 from splitgraph.core.sql import prepare_splitfile_sql, validate_import_sql
@@ -22,16 +21,17 @@ from splitgraph.engine import get_engine
 from splitgraph.engine.postgres.engine import PostgresEngine
 from splitgraph.exceptions import ImageNotFoundError, SplitfileError
 from splitgraph.hooks.mount_handlers import mount
+
+from ..core.output import Color, conn_string_to_dict, pluralise, truncate_line
+from ..core.types import ProvenanceLine
 from ._parsing import (
-    parse_commands,
+    extract_all_table_aliases,
     extract_nodes,
     get_first_or_none,
-    parse_image_spec,
-    extract_all_table_aliases,
+    parse_commands,
     parse_custom_command,
+    parse_image_spec,
 )
-from ..core.output import pluralise, truncate_line, conn_string_to_dict
-from ..core.types import ProvenanceLine
 
 
 def _combine_hashes(hashes: List[str]) -> str:
@@ -81,7 +81,7 @@ def _get_local_image_for_import(hash_or_tag: str, repository: Repository) -> Tup
     else:
         # For local repositories, first try to pull them to see if they are clones of a remote.
         if source_repo.upstream:
-            source_repo.pull()
+            source_repo.pull(single_image=hash_or_tag)
         source_image = source_repo.images[hash_or_tag]
 
     return source_image, repo_is_temporary
@@ -169,14 +169,13 @@ def execute_commands(
     """
     if params is None:
         params = {}
-    if output and repository_exists(output) and output_base is not None:
-        output.images.by_hash(output_base).checkout()
     # Use a random target schema if unspecified.
     output = output or Repository.from_schema("output_%0.2x" % getrandbits(16))
 
     # Don't initialize the output until a command writing to it asks us to
     # (otherwise we might have a FROM ... AS output_name change it).
     repo_created = False
+    output_base_checked_out = False
 
     def _initialize_output(output):
         if not repository_exists(output):
@@ -184,7 +183,18 @@ def execute_commands(
             output.init()
             repo_created = True
 
-    from splitgraph.commandline.common import Color
+        nonlocal output_base_checked_out
+        if (
+            not output_base_checked_out
+            and output
+            and repository_exists(output)
+            and output_base is not None
+        ):
+            # If we're running commands and the Splitfile doesn't start with FROM to set the base
+            # image, check out the output_base (delay it so that checking out 000... and then
+            # running FROM doesn't do redundant work).
+            checkout_if_changed(output, output_base)
+            output_base_checked_out = True
 
     node_list = parse_commands(commands, params=params)
 
@@ -200,6 +210,7 @@ def execute_commands(
             )
             if node.expr_name == "from":
                 output, maybe_provenance_line = _execute_from(node, output)
+                output_base_checked_out = True
                 if maybe_provenance_line:
                     provenance.append(maybe_provenance_line)
 
@@ -233,6 +244,21 @@ def execute_commands(
         raise
 
 
+def checkout_if_changed(repository: Repository, image_hash: str) -> None:
+    if (
+        repository.head is None
+        or (repository.head.image_hash != image_hash)
+        or repository.has_pending_changes()
+    ):
+        repository.images.by_hash(image_hash).checkout()
+    else:
+        logging.info(
+            "Skipping checkout of %s as %s has it checked out " "and there have been no changes",
+            image_hash,
+            repository,
+        )
+
+
 def _execute_sql(node: Node, output: Repository) -> ProvenanceLine:
     # Calculate the hash of the layer we are trying to create.
     # Since we handle the "input" hashing in the import step, we don't need to care about the sources here.
@@ -301,16 +327,15 @@ def _execute_from(node: Node, output: Repository) -> Tuple[Repository, Optional[
         repository, tag_or_hash = parse_image_spec(repo_source)
         source_repo = lookup_repository(repository.to_schema(), include_local=True)
 
-        if source_repo.engine.name == "LOCAL":
+        if source_repo.engine.name == "LOCAL" and source_repo.upstream:
             # For local repositories, make sure to update them if they've an upstream
-            if source_repo.upstream:
-                source_repo.pull()
+            source_repo.pull(single_image=tag_or_hash)
 
         # Get the target image hash from the source repo: otherwise, if the tag is, say, 'latest' and
         # the output has just had the base commit (000...) created in it, that commit will be the latest.
         clone(source_repo, local_repository=output, download_all=False)
         source_hash = source_repo.images[tag_or_hash].image_hash
-        output.images.by_hash(source_hash).checkout()
+        checkout_if_changed(output, source_hash)
         provenance = {
             "type": "FROM",
             "source_namespace": source_repo.namespace,
